changeset 17601:2dd1c9442974

(edt-emulation-on): Load edt-pc.el under Windows.
author Richard M. Stallman <rms@gnu.org>
date Wed, 30 Apr 1997 02:13:02 +0000
parents 0dc8180c2e7a
children 39b58a508be6
files lisp/emulation/edt.el
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/emulation/edt.el	Wed Apr 30 01:12:24 1997 +0000
+++ b/lisp/emulation/edt.el	Wed Apr 30 02:13:02 1997 +0000
@@ -1482,8 +1482,8 @@
 (defun edt-emulation-on ()
   "Turn on EDT Emulation."
   (interactive)
-  ;; If using MS-DOS, need to load edt-pc.el
-  (if (eq system-type 'ms-dos)
+  ;; If using MS-DOS or Windows, need to load edt-pc.el
+  (if (memq system-type '(ms-dos windows-nt))
       (setq edt-term "pc")
     (setq edt-term (getenv "TERM")))
   ;; All DEC VT series terminals are supported by loading edt-vt100.el